@@ -13,6 +13,7 @@ int distance_char (const char * word1,
     int matrix[2][len2 + 1];
     int i;
     int j;
+    int large_value;
 
     /*
       Initialize the 0 row of "matrix".
@@ -24,6 +25,18 @@ int distance_char (const char * word1,
 
      */
 
+    if (max >= 0) {
+        large_value = max + 1;
+    }
+    else {
+        if (len2 > len1) {
+            large_value = len2;
+        }
+        else {
+            large_value = len1;
+        }
+    }
+
     for (j = 0; j <= len2; j++) {
         matrix[0][j] = j;
     }
@@ -44,12 +57,14 @@ int distance_char (const char * word1,
 
         c1 = word1[i-1];
         min_j = 1;
-        if (i > max) {
-            min_j = i - max;
-        }
         max_j = len2;
-        if (len2 > max + i) {
-            max_j = max + i;
+        if (max >= 0) {
+            if (i > max) {
+                min_j = i - max;
+            }
+            if (len2 > max + i) {
+                max_j = max + i;
+            }
         }
         col_min = INT_MAX;
         next = i % 2;
@@ -64,7 +79,7 @@ int distance_char (const char * word1,
         for (j = 1; j <= len2; j++) {
             if (j < min_j || j > max_j) {
                 /* Put a large value in there. */
-                matrix[next][j] = max + 1;
+                matrix[next][j] = large_value;
             }
             else {
                 char c2;
@@ -106,11 +121,13 @@ int distance_char (const char * word1,
                 col_min = matrix[next][j];
             }
         }
-        if (col_min > max) {
-            /* All the elements of the ith column are greater than the
-               maximum, so no match less than or equal to max can be
-               found by looking at succeeding columns. */
-            return max + 1;
+        if (max >= 0) {
+            if (col_min > max) {
+                /* All the elements of the ith column are greater than the
+                   maximum, so no match less than or equal to max can be
+                   found by looking at succeeding columns. */
+                return large_value;
+            }
         }
     }
     return matrix[len1 % 2][len2];
